<?php

namespace App\Http\Controllers;

use App\Models\Article;
use App\Models\Category;
use App\Models\GlobalFunction;
use App\Models\Pages;
use Illuminate\Http\Request;

class ArticleController extends Controller
{
    public function articles()
    {
        $categories = Category::get();
        $data = Pages::first();
        return view('articles', [
            'categories' => $categories,
            'data' => $data->privacy
        ]);
    }

    public function articleList(Request $request)
    {
        $totalData = Article::count();
        $rows = Article::orderBy('id', 'DESC')->get();
        $result = $rows;
        $columns = [
            0 => 'id',
            1 => 'image',
        ];
        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $columns[$request->input('order.0.column')];
        $dir = $request->input('order.0.dir');
        $totalFiltered = $totalData;
        if (empty($request->input('search.value'))) {
            $result = Article::offset($start)
                ->limit($limit)
                ->orderBy($order, $dir)
                ->get();
        } else {
            $search = $request->input('search.value');
            $result = Article::Where('title', 'LIKE', "%{$search}%")
                ->offset($start)
                ->limit($limit)
                ->orderBy($order, $dir)
                ->get();
            $totalFiltered = Article::Where('title', 'LIKE', "%{$search}%")->count();
        }
        $data = [];
        foreach ($result as $item) {
  
            $imageUrl = GlobalFunction::createMediaUrl($item->image);

            $title = '<div class="itemDescription">'. $item->title .'</div>';

            if ($item->image != null) {
                $image = "<img src=". $imageUrl ." class='tbl_img'>";
            } else {
                $image = "<img src='./asset/img/placeholder-image.png' class='tbl_img'>";
            }
            if ($item->image == null) {
                $imageUrl = "null";
            }

            $edit = '<a href="#" rel='.$item->id.'
                                 data-title="'.$item->title.'"
                                 data-image="'.$imageUrl.'"  
                                 data-category_id="'.$item->category_id.'"
                                 data-content="'.$item->content.'"
                                 class="btn edit btn-success me-3">' . __('Edit') . '</a>'; 
            $delete = '<a href="#" class="btn delete btn-danger" rel=' . $item->id . '>' . __('Delete') . '</a>';
            $action = '<span class="float-end">'. $edit . $delete .' </span>' ;

            $data[] = [   
                $image,           
                $title,
                $item->category->title,
                $action
            ];
        }
        $json_data = array(
            "draw"            => intval($request->input('draw')),
            "recordsTotal"    => intval($totalData),
            "recordsFiltered" => $totalFiltered,
            "data"            => $data
        );
        echo json_encode($json_data);
        exit();

    }

    public function addArticle(Request $request)
    {
        $article = new Article();
        $article->title = $request->title;
        $article->category_id = $request->category_id;
        
        $imageFile = $request->file('image');
        $imagePath = GlobalFunction::saveFileAndGivePath($imageFile);
        $article->image = $imagePath;
        
        $content = str_replace('"', "'", $request->content);
        $article->content = $content;

        $article->save();

        return response()->json([
            'status' => true,
            'message' => 'Article added successfully',
            'data' => $article,
        ]);
        
    }

    public function updateArticle(Request $request)
    {
        $article = Article::where('id', $request->article_id)->first();
        if ($article == null) {
            return response()->json([
                'status' => false,
                'message' => 'Article not found',
            ]);            
        }
        
        if ($request->has('title')) {
            $article->title = $request->title;
        }
        if ($request->has('category_id')) {
            $article->category_id = $request->category_id;
        }
        if ($request->has('type')) {
            $article->type = $request->type;
        }
        if ($request->has('content')) {
            $content = str_replace('"', "'", $request->content);
            $article->content = $content;
        }
        if ($request->hasFile('image')) {
            GlobalFunction::deleteFile($article->image);
            $file = $request->file('image');
            $imagePath = GlobalFunction::saveFileAndGivePath($file);
            $article->image = $imagePath;
        }
        $article->save();

        return response()->json([
            'status' => true,
            'message' => 'Article updated successfully',
        ]);
    }

    public function deleteArticle(Request $request)
    {
        $article = Article::where('id', $request->article_id)->first();
        
        if ($article == null) {
            return response()->json([
                'status' => false,
                'message' => 'Article Not Found',
            ]);
        }
        GlobalFunction::deleteFile($article->image);
        $article->delete();

        return response()->json([
            'status' => true,
            'message' => 'Article delete successfully',
        ]);
    }
}
