<?php
namespace App\Http\Controllers;

use App\Models\Article;
use App\Models\Category;
use App\Models\GlobalFunction;
use App\Models\Music;
use Illuminate\Http\Request;

class CategoryController extends Controller
{
    public function categories()
    {
        return view('categories');
    }
    
    public function categoryList(Request $request)
    {
        $totalData = Category::count();
        $rows = Category::orderBy('id', 'DESC')->get();
        $result = $rows;
        $columns = [
            0 => 'id',
            1 => 'image',
        ];
        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $columns[$request->input('order.0.column')];
        $dir = $request->input('order.0.dir');
        $totalFiltered = $totalData;
        if (empty($request->input('search.value'))) {
            $result = Category::offset($start)
                ->limit($limit)
                ->orderBy($order, $dir)
                ->get();
        } else {
            $search = $request->input('search.value');
            $result = Category::Where('title', 'LIKE', "%{$search}%")
                ->offset($start)
                ->limit($limit)
                ->orderBy($order, $dir)
                ->get();
            $totalFiltered = Category::Where('title', 'LIKE', "%{$search}%")->count();
        }
        $data = [];
        foreach ($result as $item) {
  
            $imageUrl = GlobalFunction::createMediaUrl($item->image);

            if ($item->image != null) {
                $image = "<img src=". $imageUrl ." class='tbl_img'>";
            } else {
                $image = "<img src='./asset/img/placeholder-image.png' class='tbl_img'>";
            }
            if ($item->image == null) {
                $imageUrl = "null";
            }

            $edit = '<a href="#" data-title="'.$item->title.'" data-image="'.$imageUrl.'"  rel='.$item->id.' class="btn edit btn-success me-3">' . __('Edit') . '</a>'; 
            $delete = '<a href="#" class="btn delete btn-danger" rel=' . $item->id . '>' . __('Delete') . '</a>';
            $action = '<span class="float-end">'. $edit . $delete .' </span>' ;

            $data[] = [   
                $image,           
                $item->title,
                $action
            ];
        }
        $json_data = [
            'draw' => intval($request->input('draw')),
            'recordsTotal' => intval($totalData),
            'recordsFiltered' => $totalFiltered,
            'data' => $data,
        ];
        echo json_encode($json_data);
        exit();
    }

    public function addCategory(Request $request)
    {
        $category = new Category();
        $category->title = $request->title;
        if ($request->hasFile('image')) {
            $file = $request->file('image');
            $path = GlobalFunction::saveFileAndGivePath($file);
            $category->image = $path;
        }
        $category->save();

        return response()->json([
            'status' => true,
            'message' => 'Category Added Successfully',
            'data' => $category,
        ]);
        
    }

    public function updateCategory(Request $request)
    {
        $category = Category::where('id', $request->category_id)->first();

        if ($category == null) {
            return response()->json([
                'status' => false,
                'message' => 'Category Not Found',
            ]);
        } else {
            $category->title = $request->title;
            
            if ($request->hasFile('image')) {
                GlobalFunction::deleteFile($category->image); 

                $file = $request->file('image');
                $path = GlobalFunction::saveFileAndGivePath($file);
                $category->image = $path;
            }

            $category->save();

            return response()->json([
                'status' => true,
                'message' => 'Category Updated Successfully',
            ]);
        
        }
    }
    
    public function deleteCategory(Request $request)
    {
        $category = Category::where('id', $request->category_id)->first();

        if ($category == null) {
            return response()->json([
                'status' => false,
                'message' => 'Category Not Found',
            ]);
        }

        $musics = Music::where('category_id', $request->category_id)->get();
        $musics->each->delete();
        
        $articles = Article::where('category_id', $request->category_id)->get();
        $articles->each->delete();

        GlobalFunction::deleteFile($category->image);
        $category->delete();

        return response()->json([
            'status' => true,
            'message' => 'Category Delete Successfully',
        ]);
    } 

     
}
