<?php

namespace App\Http\Controllers;

use App\Models\Category;
use App\Models\GlobalFunction;
use App\Models\Music;
use Illuminate\Http\Request;

class MusicController extends Controller
{
    public function musics()
    {
        $categories = Category::get();
        return view('musics', [
            'categories' => $categories,
        ]);
    }

    public function musicList(Request $request)
    {
        $totalData = Music::count();
        $rows = Music::orderBy('id', 'DESC')->get();
        $result = $rows;
        $columns = [
            0 => 'id',
            1 => 'image',
        ];
        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $columns[$request->input('order.0.column')];
        $dir = $request->input('order.0.dir');
        $totalFiltered = $totalData;
        if (empty($request->input('search.value'))) {
            $result = Music::offset($start)
                ->limit($limit)
                ->orderBy($order, $dir)
                ->get();
        } else {
            $search = $request->input('search.value');
            $result = Music::Where('title', 'LIKE', "%{$search}%")
                ->offset($start)
                ->limit($limit)
                ->orderBy($order, $dir)
                ->get();
            $totalFiltered = Music::Where('title', 'LIKE', "%{$search}%")->count();
        }
        $data = [];
        foreach ($result as $item) {
  
            $imageUrl = GlobalFunction::createMediaUrl($item->image);
            $musicUrl = GlobalFunction::createMediaUrl($item->sound);

            if ($item->image != null) {
                $image = "<img src=". $imageUrl ."  data-original=". $imageUrl ." class='tbl_img lazy'>";
            } else {
                $image = "<img src='./asset/img/placeholder-image.png' class='tbl_img lazy' data-original='./asset/img/placeholder-image.png'>";
            }
            if ($item->image == null) {
                $imageUrl = "null";
            }

            if($item->type == 1){
                $type = '<span class="badge theme-bg px-3">' . __('Premium') . '</span>';
            } else{
                $type = '<span class="badge badge-info px-3">' . __('Free') . '</span>';
            }

            $plays = '<span class="badge badge-warning px-3 text-dark fw-semibold plays-count">'.$item->plays.'</span>';
  
            if ($item->is_featured == 1) {
                $featured = '<div class="checkbox-slider">
                <label>
                    <input type="checkbox" class="d-none featured"  checked rel="' . $item->id . '" value="' . $item->is_featured . '" >
                    <span class="toggle_background">
                        <div class="circle-icon"></div>
                        <div class="vertical_line"></div>
                    </span>
                </label>
            </div>';
            } else {
                $featured = '<div class="checkbox-slider">
                <label>
                    <input type="checkbox" class="d-none featured"  rel="' . $item->id . '" value="' . $item->is_featured . '" >
                    <span class="toggle_background">
                        <div class="circle-icon"></div>
                        <div class="vertical_line"></div>
                    </span>
                </label>
            </div>';
            }

            $music = '<audio id="show_music" src='. $musicUrl .' controls="" style="width:100%;"></audio>';
            
            $title = '<div class="itemDescription">'. $item->title .'</div>';

            $edit = '<a href="#" rel='.$item->id.'
                                 data-title="'.$item->title.'"
                                 data-image="'.$imageUrl.'"
                                 data-category_id="'.$item->category_id.'"
                                 data-type="'.$item->type.'"
                                 data-sound="'.$musicUrl.'"
                                 class="btn edit btn-success me-3">' . __('Edit') . '</a>'; 
            $delete = '<a href="#" class="btn delete btn-danger" rel=' . $item->id . '>' . __('Delete') . '</a>';
            $action = '<span class="float-end">'. $edit . $delete .' </span>' ;

            $data[] = [   
                $image,
                $music,
                $title,
                $plays,
                $item->category->title,
                $type,
                $featured,
                $action
            ];
        }
        $json_data = [
            'draw' => intval($request->input('draw')),
            'recordsTotal' => intval($totalData),
            'recordsFiltered' => $totalFiltered,
            'data' => $data,
        ];
        echo json_encode($json_data);
        exit();
    }

    public function addMusic(Request $request)
    {
        $music = new Music();
        $music->title = $request->title;
        $music->category_id = $request->category_id;
        $music->type = $request->type;
        
        $imageFile = $request->file('image');
        $imagePath = GlobalFunction::saveFileAndGivePath($imageFile);
        $music->image = $imagePath;
        
        $audioFile = $request->file('audio');
        $audioPath = GlobalFunction::saveFileAndGivePath($audioFile);
        $music->sound = $audioPath;

        $music->save();

        return response()->json([
            'status' => true,
            'message' => 'Music added successfully',
            'data' => $music,
        ]);
        
    }

    public function updateFeatured(Request $request)
    {
        $music = Music::where('id', $request->id)->first();
        if ($music == null) {
            return response()->json([
                'status' => false,
                'message' => 'Music not found',
            ]);            
        }
        
        $music->is_featured = $request->is_featured;
        $music->save();

        return response()->json([
            'status' => true,
            'message' => 'Music updated successfully',
        ]);
    }

    public function updateMusic(Request $request)
    {
        $music = Music::where('id', $request->music_id)->first();

        if ($music == null) {
            return response()->json([
                'status' => false,
                'message' => 'Music Not Found',
            ]);
        } else {

            if ($request->has('title')) {
                $music->title = $request->title;
            }
            if ($request->has('category_id')) {
                $music->category_id = $request->category_id;
            }
            if ($request->has('type')) {
                $music->type = $request->type;
            }

            if ($request->hasFile('image')) {
                GlobalFunction::deleteFile($music->image);
                $file = $request->file('image');
                $imagePath = GlobalFunction::saveFileAndGivePath($file);
                $music->image = $imagePath;
            }
            
            if ($request->hasFile('audio')) {
                GlobalFunction::deleteFile($music->sound);
                $audioFile = $request->file('audio');
                $filePath = GlobalFunction::saveFileAndGivePath($audioFile);
                $music->sound = $filePath;
            }

            $music->save();

            return response()->json([
                'status' => true,
                'message' => 'Music updated successfully',
            ]);
        
        }
    }
    
    public function deleteMusic(Request $request)
    {
        $music = Music::where('id', $request->music_id)->first();
        
        if ($music == null) {
            return response()->json([
                'status' => false,
                'message' => 'Music Not Found',
            ]);
        }
        GlobalFunction::deleteFile($music->image);
        GlobalFunction::deleteFile($music->sound);
        $music->delete();

        return response()->json([
            'status' => true,
            'message' => 'Music delete successfully',
        ]);
    }

    public function playSound(Request $request)
    {
        $music = Music::where('id', $request->music_id)->first();
        
        if ($music == null) {
            return response()->json([
                'status' => false,
                'message' => 'Music Not Found',
            ]);
        }

        $music->plays += 1;
        $music->save();

        return response()->json([
            'status' => true,
            'message' => 'Music play successfully',
            'data' => $music,
        ]);

    }




}
