<?php

namespace App\Http\Controllers;
 
use App\Models\Quote;
use Illuminate\Http\Request;

class QuoteController extends Controller
{
    public function quotes()
    {
        return view('quotes');
    }

    public function quoteList(Request $request)
    {
        $totalData = Quote::count();
        $rows = Quote::orderBy('id', 'DESC')->get();
        $result = $rows;
        $columns = [
            0 => 'id',
            1 => 'title',
        ];
        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $columns[$request->input('order.0.column')];
        $dir = $request->input('order.0.dir');
        $totalFiltered = $totalData;
        if (empty($request->input('search.value'))) {
            $result = Quote::offset($start)
                ->limit($limit)
                ->orderBy($order, $dir)
                ->get();
        } else {
            $search = $request->input('search.value');
            $result = Quote::Where('quotes', 'LIKE', "%{$search}%")
                ->offset($start)
                ->limit($limit)
                ->orderBy($order, $dir)
                ->get();
            $totalFiltered = Quote::Where('quotes', 'LIKE', "%{$search}%")->count();
        }
        $data = [];
        foreach ($result as $item) {

            $quotes = '<div class="itemDescription">'. $item->quotes .'</div>';
   
            $edit = '<a href="#" rel='.$item->id.' data-title="'.$item->quotes.'" class="btn edit btn-success me-3">' . __('Edit') . '</a>'; 
            $delete = '<a href="#" class="btn delete btn-danger" rel=' . $item->id . '>' . __('Delete') . '</a>';
            $action = '<span class="float-end">'. $edit . $delete .' </span>' ;

            $data[] = [        
                $quotes,
                $action
            ];
        }
        $json_data = [
            'draw' => intval($request->input('draw')),
            'recordsTotal' => intval($totalData),
            'recordsFiltered' => $totalFiltered,
            'data' => $data,
        ];
        echo json_encode($json_data);
        exit();

    }
    
    public function addQuote(Request $request)
    {
        $quote = new Quote();
        $quote->quotes = $request->title;
        $quote->save();

        return response()->json([
            'status' => true,
            'message' => 'Quote added successfully',
            'data' => $quote,
        ]);
    }

    public function updateQuote(Request $request)
    {
        $quote = Quote::where('id', $request->quote_id)->first();
        if ($quote == null) {
            return response()->json([
                'status' => false,
                'message' => 'Quote not found',
            ]);            
        }

        $quote->quotes = $request->title;
        $quote->save();

        return response()->json([
            'status' => true,
            'message' => 'Quote updated successfully',
        ]);
    }

    public function deleteQuote(Request $request)
    {
        $quote = Quote::where('id', $request->quote_id)->first();
        
        if ($quote == null) {
            return response()->json([
                'status' => false,
                'message' => 'Quote Not Found',
            ]);
        }
        $quote->delete();

        return response()->json([
            'status' => true,
            'message' => 'Quote delete successfully',
        ]);
    }
}
