<?php

namespace App\Http\Controllers;

use App\Models\Admin;
use App\Models\Article;
use App\Models\Category;
use App\Models\GlobalSettings;
use App\Models\Music;
use App\Models\Notification;
use App\Models\Quote;
use App\Models\User;
use Illuminate\Http\Request;

include './app/Class/AgoraDynamicKey/RtcTokenBuilder.php';

class SettingsController extends Controller
{
    function index()
    {
        $allCategories = Category::count();
        $users = User::count();
        $categories = Category::count();
        $musics = Music::count();
        $articles = Article::count();
        $quotes = Quote::count();
        $notifications = Notification::count();

        return view('index', [
            'allCategories' => $allCategories, 
            'users' => $users,
            'categories' => $categories,
            'musics' => $musics,
            'articles' => $articles,
            'quotes' => $quotes,
            'notifications' => $notifications,
        ]);
    }

    public function setting()
    {
        $setting = GlobalSettings::first();
        
        return view('setting', [
            'setting' => $setting
        ]);
    }

    public function fetchSettings()
    {
        $data = GlobalSettings::first();
        return response()->json([
            'status' => true,
            'message' => 'Fetch Setting',
            'data' => $data,
        ]);
    }

    public function saveSettings(Request $request)
    {
        $setting = GlobalSettings::first();

        if ($setting == null) {
            return response()->json([
                'status' => false,
                'message' => 'setting Not Found',
            ]);
        } 
        if ($request->has('app_name')) {
            $setting->app_name = $request->app_name;
            $request->session()->put('app_name', $setting['app_name']);
        }
        if ($request->has('currency')) {
            $setting->currency = $request->currency;
            $request->session()->put('currency', $setting['currency']);
        }
        $setting->save();
            
        return response()->json([
            'status' => true,
            'message' => 'Setting Updated Successfully',
        ]);

    }

    public function changePassword(Request $request)
    {
        $admin = Admin::where('user_type', 1)->first();
        if ($admin) {
            if ($request->has('user_password')) {
                if ($admin->user_password == $request->user_password) {
                    $admin->user_password = $request->new_password;
                    $admin->save();
                    return response()->json([
                        'status' => true,
                        'message' => 'Change Password',
                    ]);
                } else {
                    return response()->json([
                        'status' => false,
                        'message' => 'Old Password does not match',
                    ]);
                }
            }
        } else {
            return response()->json([
                'status' => false,
                'message' => 'Admin not found',
            ]);
        }
    }
 
    public function admobSettingSave(Request $request)
    {
        $admobSetting = GlobalSettings::first();

        if ($admobSetting == null) {
            return response()->json([
                'status' => false,
                'message' => 'Admob Not Found',
            ]);
        } 
        
        $admobSetting->banner_id_android = $request->banner_id_android;
        $admobSetting->intersial_id_android = $request->intersial_id_android;
        $admobSetting->banner_id_ios = $request->banner_id_ios;
        $admobSetting->intersial_id_ios = $request->intersial_id_ios;
        $admobSetting->save();
            
        return response()->json([
            'status' => true,
            'message' => 'Admob Updated Successfully',
        ]);
    }

    // API

    public function fetchAllData()
    {
        
        $categories = Category::get(); 
        $musics = Music::get(); 
        $articles = Article::get(); 
        $quotes = Quote::get(); 
        $settings = GlobalSettings::first(); 

        return response()->json([
            'status' => true,
            'message' => 'Fetch home page data successfully', 
            'musics' => $musics,
            'categories' => $categories,
            'articles' => $articles,
            'quotes' => $quotes,
            'settings' => $settings,
        ]);
    }
 
}