$(document).ready(function () {
  $(".sideBarli").removeClass("activeLi");
  $(".musicSideA").addClass("activeLi");

  var selectedMusicID = 0;
   
  $("#musicTable").dataTable({
    processing: true,
    serverSide: true,
    
    serverMethod: "post",
    aaSorting: [[0, "desc"]],
    language: {
      paginate: {
        next: '<svg viewBox="0 0 24 24" width="24" height="24" stroke="currentColor" stroke-width="2" fill="none" stroke-linecap="round" stroke-linejoin="round" class="css-i6dzq1"><polyline points="9 18 15 12 9 6"></polyline></svg>',
        previous:
          '<svg viewBox="0 0 24 24" width="24" height="24" stroke="currentColor" stroke-width="2" fill="none" stroke-linecap="round" stroke-linejoin="round" class="css-i6dzq1"><polyline points="15 18 9 12 15 6"></polyline></svg>',
      },
    },
    columnDefs: [
      {
        targets: [0, 1, 2, 3, 4, 5, 6, 7],
        orderable: false,
      },
    ],
    ajax: {
      url: `${domainUrl}musicList`,
      error: (error) => {
        console.log(error);
      },
    },
  });

  $(document).on("submit", "#addMusicForm", function (e) {
    e.preventDefault();
    if (user_type == 1) {
      let formData = new FormData($("#addMusicForm")[0]);
      $.ajax({
        type: "POST",
        url: `${domainUrl}addMusic`,
        data: formData,
        contentType: false,
        processData: false,
        success: function (response) {
          if (response.status == false) {
            console.log(response.message);
            iziToast.show({
              title: "Error",
              message: "Music not found",
              color: "red",
              position: toastPosition,
              transitionIn: transitionInAction,
              transitionOut: transitionOutAction,
              timeout: 3000,
              animateInside: false,
              iconUrl: `${domainUrl}asset/img/copy.svg`,
            });
          } else if (response.status == true) {
            iziToast.show({
              title: "Success",
              message: "Music Added Successfully",
              color: "green",
              position: toastPosition,
              transitionIn: transitionInAction,
              transitionOut: transitionOutAction,
              timeout: 3000,
              animateInside: false,
              iconUrl: `${domainUrl}asset/img/check-circle.svg`,
            });
            $("#musicTable").DataTable().ajax.reload(null, false);
            $("#musicModal").modal("hide");
            $("#musicModal").load(location.href + " #musicModal>*", "");
          }
        },
      });
    } else {
      iziToast.show({
        title: "Oops",
        message: "You are tester",
        color: "red",
        position: toastPosition,
        transitionIn: transitionInAction,
        transitionOut: transitionOutAction,
        timeout: 3000,
        animateInside: false,
        iconUrl: `${domainUrl}asset/img/x.svg`,
      });
    }
  });

  $("#musicTable").on("click", ".edit", function (e) {
    e.preventDefault();

    var id = $(this).attr("rel");
    var title = $(this).data("title");
    var category_id = $(this).data("category_id");
    var type = $(this).data("type");
    var image = $(this).data("image");
    var sound = $(this).data("sound");

    selectedMusicID = id;
    $("#edit_title").val(title);
    $("#edit_category").val(category_id);
    $("#edit_type").val(type);

    if (image != null) {
      $("#edit_musicImg").attr("src", `${image}`);
    } else {
      $("#edit_musicImg").attr("src", "./asset/img/placeholder-image.png");
    }
    $("#edit_audio").attr("src", `${sound}`);

    $("#editMusicModal").modal("show");
  });

  $(document).on("submit", "#editMusicForm", function (e) {
    e.preventDefault();
    if (user_type == 1) {
      let editformData = new FormData($("#editMusicForm")[0]);
      editformData.append("music_id", selectedMusicID);
      $.ajax({
        type: "POST",
        url: `${domainUrl}updateMusic`,
        data: editformData,
        contentType: false,
        processData: false,
        success: function (response) {
          if (response.status == 404) {
            console.log(response.message);
          } else if (response.status == false) {
            iziToast.show({
              title: "Error",
              message: "Music not found",
              color: "red",
              position: toastPosition,
              transitionIn: transitionInAction,
              transitionOut: transitionOutAction,
              timeout: 3000,
              animateInside: false,
              iconUrl: `${domainUrl}asset/img/x.svg`,
            });
          } else if (response.status == true) {
            iziToast.show({
              title: "Success",
              message: "Music Update Successfully",
              color: "green",
              position: toastPosition,
              transitionIn: transitionInAction,
              transitionOut: transitionOutAction,
              timeout: 3000,
              animateInside: false,
              iconUrl: `${domainUrl}asset/img/check-circle.svg`,
            });
            $("#musicTable").DataTable().ajax.reload(null, false);
            $("#editMusicModal").modal("hide");
          }
        },
      });
    } else {
      iziToast.show({
        title: "Oops",
        message: "You are tester",
        color: "red",
        position: toastPosition,
        transitionIn: transitionInAction,
        transitionOut: transitionOutAction,
        timeout: 3000,
        animateInside: false,
        iconUrl: `${domainUrl}asset/img/x.svg`,
      });
    }
  });

  $("#musicTable").on("click", ".delete", function (e) {
    e.preventDefault();
    if (user_type == 1) {
      var id = $(this).attr("rel"); 
      swal({
        title: "Are you sure?",
        icon: "error",
        buttons: true,
        dangerMode: true,
        buttons: ["Cancel", "Yes"],
      }).then((deleteValue) => {
        if (deleteValue) {
          if (deleteValue == true) {
            $.ajax({
              type: "POST",
              url: `${domainUrl}deleteMusic`,
              dataType: "json",
              data: {
                music_id: id,
              },
              success: function (response) {
                if (response.status == false) {
                  console.log(response.message);
                } else if (response.status == true) {
                  iziToast.show({
                    title: "Success",
                    message: "Music delete successfully",
                    color: "green",
                    position: toastPosition,
                    transitionIn: transitionInAction,
                    transitionOut: transitionOutAction,
                    timeout: 3000,
                    animateInside: false,
                    iconUrl: `${domainUrl}asset/img/check-circle.svg`,
                  });
                  $("#musicTable").DataTable().ajax.reload(null, false);
                }
              },
            });
          }
        }
      });
    } else {
      iziToast.show({
        title: "Oops",
        message: "You are tester",
        color: "red",
        position: toastPosition,
        transitionIn: transitionInAction,
        transitionOut: transitionOutAction,
        timeout: 3000,
        animateInside: false,
        iconUrl: `${domainUrl}asset/img/x.svg`,
      });
    }
  });

  $(document).on("change", ".featured", function (event) {
    event.preventDefault();
    if (user_type == 1) {
      $id = $(this).attr("rel");
      if ($(this).prop("checked") == true) {
        $value = 1;
        console.log("Checkbox is Checked.");
        console.log("1 == true");
        iziToast.show({
          title: "Success",
          message: "Music added in featured item",
          color: "green",
          position: toastPosition,
          transitionIn: transitionInAction,
          transitionOut: transitionOutAction,
          timeout: 3000,
          animateInside: false,
          iconUrl: `${domainUrl}asset/img/check-circle.svg`,
        });
      } else {
        $value = 0;
        console.log("Checkbox is unchecked.");
        console.log("0 == false");
        iziToast.show({
          title: "Success",
          message: "Music removed from featured Item",
          color: "green",
          position: toastPosition,
          transitionIn: transitionInAction,
          transitionOut: transitionOutAction,
          timeout: 3000,
          animateInside: false,
          iconUrl: `${domainUrl}asset/img/check-circle.svg`,
        });
      }
      $.post(
        `${domainUrl}updateFeatured`,
        {
          id: $id,
          is_featured: $value,
        },
        function (returnedData) {
          console.log(returnedData);
          $("#musicTable").DataTable().ajax.reload(null, false);
        }
      ).fail(function (error) {
        console.log(error);
      });
    } else {
      iziToast.show({
        title: "Oops!",
        message: "You are Tester",
        color: "red",
        position: toastPosition,
        transitionIn: transitionInAction,
        transitionOut: transitionOutAction,
        timeout: 3000,
        animateInside: false,
        iconUrl: `${domainUrl}asset/img/check-circle.svg`,
      });
      $("#wallpaperTable").DataTable().ajax.reload(null, false);
      $("#liveWallpaperTable").DataTable().ajax.reload(null, false);
    }
  });
});
