@extends('include.app')
@section('header')
    <script src="{{ asset('asset/script/article.js') }}"></script>
@endsection

@section('content')

<section class="section">
    <div class="card">
        <div class="card-header">
            <div class="page-title w-100">
                <div class="d-flex align-items-center justify-content-between">
                    <h4 class="mb-0 fw-semibold">{{ __('Articles') }}</h4>
                    <button type="button" class="btn theme-bg theme-btn text-white text-capitalize" data-bs-toggle="modal"
                        data-bs-target="#articleModal">
                        {{ __('Add Article') }}
                    </button>
                </div>
            </div>
        </div>
        <div class="card-body">
            <table class="table table-striped w-100" id="articleTable">
                <thead>
                    <tr>
                        <th width="100px">{{ __('Image') }}</th>
                        <th>{{ __('Title') }}</th>
                        <th width="200px">{{ __('Category') }}</th>
                        <th width="200px" style="text-align: right">{{ __('Action') }}</th>
                    </tr>
                </thead>
            </table>
        </div>
    </div>  
</section>


<!-- Article Modal -->
<div class="modal fade" id="articleModal" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-sm-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h1 class="modal-title fs-5 fw-semibold text-capitalize" id="exampleModalLabel">{{ __('Add Article') }}</h1>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <form id="addArticleForm" method="post">
                <div class="modal-body">
                    <div class="row">
                        <div class="col-md-8">
                            <div class="form-group">
                                <label for="title" class="form-label">{{ __('Title') }}</label>
                                <input type="text" class="form-control" name="title" id="title" required="">
                            </div>
                            <div class="form-group">
                                <label class="form-label">{{ __('Category') }}</label>
                                <select name="category_id" id="category" class="form-control" required>
                                    <option value="" disabled selected>{{ __('Select Option') }}</option>
                                    @foreach ($categories as $category)
                                    <option value="{{ $category->id }}">{{ $category->title }}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-group">
                                <label for="image" class="form-label">{{ __('Image') }}</label>
                                <div class="posterImg">
                                    <div class="upload-options">
                                        <label for="poster"> 
                                        <input type="file" accept=".png, .jpg, .jpeg, .webp" onchange="loadFile(event)" name="image" id="poster" required>
                                        </label>
                                    </div>
                                    <img id="posterImg" class="custom_img img-fluid" src="{{ asset('asset/img/placeholder-image.png')}}">
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="form-group">
                        <label for="title" class="form-label">{{ __('Content') }}</label>
                        <div id="editor" class="quillEditor"></div>
                        <textarea name="content" style="display:none" id="hiddenArea"></textarea>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn modal-cancel-btn"
                        data-bs-dismiss="modal">{{ __('Cancel') }}</button>
                    <button type="submit" class="btn theme-btn text-white saveButton">{{ __('Save') }}</button>
                </div>
            </form>
        </div>
    </div>
</div>


<!-- Edit article Modal -->
<div class="modal fade" id="editArticleModal" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-sm-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h1 class="modal-title fs-5 fw-semibold text-capitalize" id="exampleModalLabel">{{ __('Edit Article') }}</h1>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <form id="editArticleForm" method="post">
                <input type="hidden" id="articleID">
                <div class="modal-body">
                    <div class="row">
                        <div class="col-md-8">
                            <div class="form-group">
                                <label for="edit_title" class="form-label">{{ __('Title') }}</label>
                                <input type="text" class="form-control" name="title" id="edit_title" required="">
                            </div>
                            <div class="form-group">
                                <label for="edit_category" class="form-label">{{ __('Category') }}</label>
                                <select name="category_id" id="edit_category" class="form-control" required>
                                    <option value="" disabled selected>{{ __('Select Option') }}</option>
                                    @foreach ($categories as $category)
                                    <option value="{{ $category->id }}">{{ $category->title }}</option>
                                    @endforeach
                                </select>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-group">
                                <label for="image" class="form-label">{{ __('Image') }}</label>
                                <div class="posterImg">
                                    <div class="upload-options">
                                        <label for="editPoster"> 
                                        <input type="file" accept=".png, .jpg, .jpeg, .webp" onchange="loadFileEdit(event)" name="image" id="editPoster">
                                        </label>
                                    </div>
                                    <img id="editPosterImg" class="custom_img img-fluid" src="{{ asset('asset/img/placeholder-image.png')}}">
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="form-group">
                        <label for="title" class="form-label">{{ __('Content') }}</label>
                        <div id="editEditor" class="quillEditor"></div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn modal-cancel-btn" data-bs-dismiss="modal">{{ __('Cancel') }}</button>
                    <button type="submit" class="btn theme-btn text-white saveButton">{{ __('Save') }}</button>
                </div>
            </form>
        </div>
    </div>
</div>
  
<script>
    var loadFile = function(event) {
        var output = document.getElementById('posterImg');
        output.src = URL.createObjectURL(event.target.files[0]);
        output.onload = function() {
            URL.revokeObjectURL(output.src)
        }
    };

    var loadFileEdit = function(event) {
        var output1 = document.getElementById('editPosterImg');
        output1.src = URL.createObjectURL(event.target.files[0]); 
        output1.onload = function() {
            URL.revokeObjectURL(output1.src)
        }
        console.log(output1);
    };
</script>
@endsection
